@@ -1,9 +1,11 @@
 """Method for retrieving token for bot."""
+from http import HTTPStatus
 from typing import Dict
 from urllib.parse import urljoin
 from uuid import UUID
 
 from botx.clients.methods.base import BotXMethod, PrimitiveDataType
+from botx.clients.methods.errors import bot_not_found, unauthorized_bot
 
 
 class Token(BotXMethod[str]):
@@ -12,6 +14,10 @@ class Token(BotXMethod[str]):
     __url__ = "/api/v2/botx/bots/{bot_id}/token"
     __method__ = "GET"
     __returning__ = str
+    __errors_handlers__ = {
+        HTTPStatus.NOT_FOUND: bot_not_found.handle_error,
+        HTTPStatus.UNAUTHORIZED: unauthorized_bot.handle_error,
+    }
 
     #: ID of bot which access for token.
     bot_id: UUID
