@@ -1,8 +1,7 @@
 """Method for disabling stealth in chat."""
+from http import HTTPStatus
 from uuid import UUID
 
-import httpx
-
 from botx.clients.methods.base import AuthorizedBotXMethod
 from botx.clients.methods.errors import bot_is_not_admin, chat_not_found
 
@@ -14,8 +13,8 @@ class StealthDisable(AuthorizedBotXMethod[bool]):
     __method__ = "POST"
     __returning__ = bool
     __errors_handlers__ = {
-        httpx.codes.FORBIDDEN: bot_is_not_admin.handle_error,
-        httpx.codes.NOT_FOUND: chat_not_found.handle_error,
+        HTTPStatus.FORBIDDEN: bot_is_not_admin.handle_error,
+        HTTPStatus.NOT_FOUND: chat_not_found.handle_error,
     }
 
     #: ID of chat where stealth should be disabled.
